<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Tarayıcının dışındaki yaşam!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Sürüm %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>%1 için lisanslanmıştır</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 özgür yazılımdır ama geliştirmek değerli zaman alır.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Lütfen %2 geliştirilmesinin devam etmesi için &lt;a href=&apos;%1&apos;&gt;bağış&lt;/a&gt; yapın.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>%1&apos;i, %2 kullanarak kendi dilinize çevirin</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>% 1 tarafından desteklenmektedir</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Açık kaynaklı yazılım</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Simge %1 tarafından tasarlandı.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU Genel Kamu Lisansı&lt;/a&gt; ile yayınlanmıştır</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Kapat (&amp;C)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Lisans bilgilerini girin</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Eposta:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>Kod:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Lütfen lisans %1</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Tam sürüm, videoları duraklamadan izlemenizi sağlar.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Tam sürümü alarak, aynı zamanda %1 yaratmamdaki üstün çabamı destekleyebilirsiniz.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Demo kullan</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Lisans Girin</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Lisans Al</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>%1 tarafından</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>%n yeni videonuz var</numerusform><numerusform>%n yeni videonuz var</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Tüm Videolar</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>İzlenmemiş Videolar</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Son Güncellenen</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Son Eklenen</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Son İzlenen</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>En Çok İzlenen</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sırala</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Tümünü izlendi işaretle</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Güncellenenleri Göster</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Hiç aboneliğiniz yok. Kanallara abone olmak için yıldız simgesini kullanın.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Tüm Videolar</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>İzlenmemiş Videolar</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>İzlendi olarak İşaretle</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Aboneliği Kaldır</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Şu anda güncellenen abonelik yok.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Şuanda</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>&amp;n saat önce</numerusform><numerusform>&amp;n saat önce</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>&amp;n gün önce</numerusform><numerusform>&amp;n gün önce</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>&amp;n ay önce</numerusform><numerusform>&amp;n ay önce</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 görüntülenme</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>&amp;n hafta önce</numerusform><numerusform>&amp;n hafta önce</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation><numerusform>%n yıl önce</numerusform><numerusform>%n yıl önce</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>byte</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>byte/san</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/san</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/san</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>saniye</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>dakika</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 kaldı</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%2 de %1 indirildi</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>İndirme tamamlandı.</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>&amp;n İndirme</numerusform><numerusform>&amp;n İndirme</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Konumu değiştir...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>İndirme konumunu seçin</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>İndirme konumu değişti</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Mevcut indirmeler önceki konumda devam edecek</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>İndiriliyor: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>İndirmeler</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Çalıştırılabilir dosya belki virüs tarafından hasar görmüş olabilir.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 çalıştırılamıyor. Tekrar yüklemeyi deneyin.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Çık</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Yeniden yükle</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Bekle</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Oynat/Bekle</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dur</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Şimdiki videodan sonra oynatmayı durdur</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Sonraki video</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Önceki video</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Sesi arttır</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Sesi azalt</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Sessiz</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>İleri sar</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Geri sar</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Arama</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Anahtar kelimeye göre video ve kanal bulun</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gözat</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Kategoriye göre videoları gözat</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abonelikler</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Kanal abonelikleri</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Kendinizi rahat hissedin</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Pencere</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Küçült</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>Dur (&amp;S)</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Oynatmayı durdur ve aramaya geri dön</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Bir önceki parçaya geri dön</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Atla</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Sonraki videoya atla</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Oynat</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Oynatmaya devam et</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Tam ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Tam ekran görünümü</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Kü&amp;cültümüş Ekran</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Listeyi ve araç çubuğunu gizle</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>&amp;YouTube Sayfasını Aç</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Oynatmayı beklet ve YouTube sayfasına git</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>YouTube &amp;Linkini Kopyala</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Geçerli videonun YouTube bağlantısını panoya kopyala</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Video &amp;URL&apos;sini Kopyala</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Geçerli video akışının URL adresini panoya kopyala</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Video Bölümlerini Bul</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Doğru sırada olacak şekilde diğer video kısımlarını bul</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Kaldır</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Seçilen videoları listeden kaldır</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Y&amp;ukarı taşı</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Seçilen videoları listede yukarı taşı</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>A&amp;şağı taşı</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Seçilen videoları listede aşağı taşı</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>Son Aramaları Temizle</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Arama geçmişini sil. Bu geri alınamaz.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Gülegüle</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Website</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 İnternette</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Bağış Yap</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Lütfen %1 gelişiminin sürekliliği için destekleyin</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>%1 Hakkında</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Sesi kes</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Manuel Olarak Çalmaya Başla</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Videoları manuel olarak çalmaya başla</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;İndirmeler</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Video indirmelerinin ayrıntılarını göster</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;İndir</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Geçerli videoyu indir</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>&amp;Ekran Görüntüsü Al</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>Kanala Abone Ol (&amp;S)</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>%1 kullanarak şu an ki videoyu paylaş</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Eposta</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Eposta</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>Üstte Sabitle</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>Bu Videodan &amp;Sonra Durdur</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>Bir Sorun Bildi&amp;r</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>A&amp;ramayı Sınırla...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Dahası...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Benze&amp;r Videolar</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Şu an izlediğinize benzer videolar izleyin</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>&amp;Tarayıcıda aç...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Sınırlı Mod</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Uygunsuz içerik içerebilecek videoları gizle</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>&amp;Menü Çubuğunu Aç/Kapat</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menü</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>%1 &amp;seviyor musunuz? Değerlendirin!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>%1 Satın Al...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Uygulama</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Çalma</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Oynatma &amp;listesi</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>Payla&amp;s</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Görünüm</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Yardı&amp;m</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>%1 Sesi arttır, %2 sesi azalt</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Konumunuzu seçin</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 Açılıyor</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>%1 İndiriliyor, çıkmak istiyor musunuz?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Eğer %1&apos;İ şimdi kapatırsanız, bu indirme iptal edilecek.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Kapat ve indirmeyi iptal et</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>İndirmenin bitmesini bekle</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Hata: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Bekle</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Oynatmayı beklet</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Yükleniyor</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>&amp;Tam Ekrandan Çık</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Kalan zaman: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Ses %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Ses kapandı</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ses açık</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>En yüksek video tanımı %1 olarak ayarlı</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Şimdi gizliliğiniz güvende</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>İndirme tamamlandı</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>ALT tuşuna basarak hala menü çubuğuna erişebilirsiniz</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Şimdi YouTube bağlantısını başka bir uygulamaya yapıştırabilirsiniz</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Şimdi video akışı URL adresini başka bir uygulamaya yapıştırabilirsiniz</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Bağlantı kısıtlı bir süre için geçerli olacak.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>İndiriliyor %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>/</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>kısım</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>bölüm</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>%1 ile gönderildi</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>%1 aboneliğinden çık</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>%1 Abone Ol</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>% 1 olarak değiştirildi</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>%1 aboneliğinden çık</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>%1 Abone Ol</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation>%1 saniye geri sar</translation>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation>%1 saniye hızlı ileri sar</translation>
    </message>
    <message>
        <source>channel</source>
        <translation>kanal</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>%1 e ait yeni sürüm kullanılabilir.</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 şimdi kullanılabilir. Siz %3</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Bunu şimdi indirmek istiyor musunuz?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Bu Sürümü Geç</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Daha sonra Hatırlat</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Güncellemeyi Yükle</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>Bir video seç</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 of %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Hazırlanıyor</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Başarısız</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Tamamlandı</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Durduruldu</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>İndirme işlemini durdur</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>%1 içinde göster</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Önceki dizini aç</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>İndirme işlemini yeniden başlat</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>%1 Tane Daha Göster</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Video yok</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Daha fazla video yok</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sırala</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Alaka</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Hiti Göster</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Hit</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Herhangi bir zaman</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Bugün</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Gün</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Gün</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Süre</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Hepsi</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Kısa</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Orta</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Uzun</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>4 dakikadan kısa</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>4 - 20 dakika arası</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>20 dakikadan uzun</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kalite</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Bu yıl</translation>
    </message>
    <message>
        <source>HD</source>
        <translation>HD</translation>
    </message>
    <message>
        <source>4K</source>
        <translation>4K</translation>
    </message>
    <message>
        <source>HDR</source>
        <translation>HDR</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Tamamlandı</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;&apos;a Hoşgeldiniz</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>ve videoları izlemeye başlayın.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>bir anahtar kelime</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Giriş yapın</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Son arananlar</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Önceki kanallar</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Tam sürüme geç</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation>%1 için uzaktan kumanda mı lazım? %2&apos;yi dene!</translation>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation>%1 iyileştirmek için sürekli devam ediyorum. Bu çalışmayı destekleyin!</translation>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation>Bir güncelleme kurulmaya hazır. Güncellemek için çıkın ve kurun.</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;İleri</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>%1 Yönlendir</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Geri Dön: %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>A&amp;ramayı Sınırla</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Bunu mu demek istediniz: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Konumu değiştir...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Ekran görüntüsü %1 konumuna kaydedildi</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Ekran görüntüsü konumu değişti.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>En popülerler</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation>Trend</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>News</source>
        <translation>Yeniler</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filmler</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Oyun</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Güncelleme indiriliyor...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>%1 indiriliyor...</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation>Güncellemeleri denetle...</translation>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation>%1 sürümü mevcut...</translation>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation>%1 sürümü indiriliyor...</translation>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation>Güncellemek için Yeniden Başlat</translation>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation>%1 sürümü indirilemedi</translation>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation>Güncellemeleri denetle</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>Güncellemeyi İndir</translation>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>Güncelleme indiriliyor...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation>Güncellemeyi İndirmeyi Yeniden Dene</translation>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation>En son sürüme sahipsiniz.</translation>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation>%1 sürümü mevcut.</translation>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation>Bir güncelleme indirildi ve kurulmaya hazır.</translation>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>%1 için video akışı alınamıyor.</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Cezayir</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Arjantin</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Avustralya</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belçika</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brezilya</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Şili</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolombiya</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Çek Cumhuriyeti</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Mısır</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Fransa</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Almanya</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Gana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Yunanistan</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Macaristan</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Hindistan</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Endonezya</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>İrlanda</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>İsrail</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>İtalya</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japonya</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Ürdün</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malezya</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Meksika</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Fas</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Hollanda</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Yeni Zelanda</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nijerya</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipinler</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polonya</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusya</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Suudi Arabistan</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Güney Afrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Güney Kore</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>İspanya</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>İsviçre</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Tayvan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunus</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Türkiye</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Birleşik Arap Emirlikleri</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>İngiltere</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Dünya Çapında</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>%1 için video akışı alınamıyor.</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation>Şu anda mevcut güncelleme yok.</translation>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation>Zaten en son sürüme sahipsiniz</translation>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation>İndiriliyor %1 %2...</translation>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>%1 e ait yeni sürüm kullanılabilir.</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 şimdi kullanılabilir. Siz %3</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Bunu şimdi indirmek istiyor musunuz?</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Daha sonra Hatırlat</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>Güncellemeyi İndir</translation>
    </message>
</context>
</TS>